﻿import es
import gamethread
import langlib
import math
import playerlib
import popuplib
import random

lang_dir = "cstrike/addons/eventscripts/soccer_mod_2011/language/"

messages = langlib.Strings(lang_dir + "modules/match/messages_match.ini")
messages_common = langlib.Strings(lang_dir + "messages_common.ini")

modules = ["end", "names", "score", "time"]

# ******************** Load ********************
def load():
	load_variables()

	create_popup()

	for item in modules:
		es.load("soccer_mod_2011/modules/match/%s" % (item))

# ******************** Load variables ********************
def load_variables():
	es.set("sm_match_started", 0)
	es.set("match_paused", 0)
	es.set("period", 0)
	es.set("period_time", 0)
	es.set("minutes", 0)
	es.set("seconds", 0)
	es.set("period_running", 0)
	es.set("period_break_running", 0)
	es.set("golden_goal", 0)
	es.set("match_toss", 0)

# ******************** Create popup ********************
def create_popup():
	common = langlib.Strings(lang_dir + "popup_common.ini")
	text = langlib.Strings(lang_dir + "modules/match/popup_match.ini")

	popup = popuplib.create("sm_popup_admin_match")

	popup.addline("SOCCER MOD %s" % (text("title")))
	popup.addline(" ")

	values = ["start", "pause", "unpause", "stop", "names", "score"]
	for i in range(0, len(values)):
		popup.addline("->%s. %s" % (i + 1, text(values[i])))

	popup.addline(" ")
	popup.addline("->9. %s" % (common("back")))
	popup.addline(" ")
	popup.addline("->0. %s" % (common("close")))

	for i in range(1, 5):
		popup.select(i, popup_choice)

	popup.submenu(5, "sm_popup_admin_match_names")
	popup.submenu(6, "sm_popup_admin_match_score")

	for i in range(7, 9):
		popup.submenu(i, "sm_popup_admin_match")

	popup.submenu(9, "sm_popup_admin")

# ******************** Commands ********************
def cmd_start():
	commands("start", "start")

def cmd_pause():
	commands("pause", "pause")

def cmd_unpause():
	commands("pause", "unpause")

def cmd_stop():
	commands("stop", "stop")

def commands(cvar, type):
	tokens = {}
	userid = es.getcmduserid()
	player = playerlib.getPlayer(userid)

	if es.ServerVar("soccer_mod_allowed") == 1:
		if es.ServerVar("sm_match_public_%s_on" % (cvar)) == 1:
			if type == "start":
				start_match_check(userid)
			elif type == "pause":
				pause_match(userid)
			elif type == "unpause":
				unpause_match(userid)
			elif type == "stop":
				stop_match(userid)
		else:
			if es.exists("key", "soccer_mod_admins", player.steamid) == 1:
				try:
					if int(es.keygetvalue("soccer_mod_admins", player.steamid, "match")) == 1:
						if type == "start":
							start_match_check(userid)
						elif type == "pause":
							pause_match(userid)
						elif type == "unpause":
							unpause_match(userid)
						elif type == "stop":
							stop_match(userid)
					else:
						es.tell(userid, "#green", messages("not_allowed_match", tokens, player.get("lang")))
				except ValueError:
					es.tell(userid, "#green", messages("not_allowed_match", tokens, player.get("lang")))
			else:
				es.tell(userid, "#green", messages("stop_off", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages_common("not_allowed", tokens, player.get("lang")))

# ******************** Popup choice ********************
def popup_choice(userid, choice, popupid):
	if choice == 1:
		start_match_check(userid)
	elif choice == 2:
		pause_match(userid)
	elif choice == 3:
		unpause_match(userid)
	elif choice == 4:
		stop_match(userid)

	popuplib.send("sm_popup_admin_match", userid)

# ******************** Functions ********************
def lang_msg(text, tokens, center = 0):
	for player in playerlib.getPlayerList("#human"):
		if center == 0:
			es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))
		else:
			es.centertell(player.userid, messages(text, tokens, player.get("lang")))

def tell_all(message):
	for player in playerlib.getPlayerList("#human"):
		es.centertell(player.userid, message)

def start_match_check(userid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.ServerVar("sm_cap_fight_started") == 0:
		if es.ServerVar("sm_training_cannon_on") == 0:
			if es.ServerVar("sm_training_goals_disabled") == 0:
				if es.ServerVar("sm_match_started") == 0:
					if es.exists("keygroup", "sm_keygroup_vote") == 0:
						tokens["name"] = player.name
						lang_msg("match_started", tokens)

						start_match()
					else:
						es.tell(userid, "#green", messages("vote_active", tokens, player.get("lang")))
				else:
					es.tell(userid, "#green", messages("already_started", tokens, player.get("lang")))
			else:
				es.tell(userid, "#green", messages("no_match_goals_disabled", tokens, player.get("lang")))
		else:
			es.tell(userid, "#green", messages("no_match_cannon_on", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages("no_match_cap_fight", tokens, player.get("lang")))

def start_match():
	es.set("sm_match_started", 1)
	es.set("match_paused", 0)
	es.set("period", 1)
	es.set("period_time", 1)
	es.set("minutes", 0)
	es.set("seconds", 0)
	es.set("period_running", 0)
	es.set("period_break_running", 0)
	es.set("sm_match_score_t", 0)
	es.set("sm_match_score_ct", 0)
	es.set("sm_match_subs_t", 0)
	es.set("sm_match_subs_ct", 0)
	es.set("golden_goal", 0)
	es.set("sm_match_first_hit", 1)

	es.keygroupdelete("soccer_mod_stats")
	es.keygroupcreate("soccer_mod_stats")
	es.doblock("soccer_mod_2011/match/stats/reset_team_stats")

	es.set("match_toss", random.randint(0, 1))

	periods = int(es.ServerVar("sm_match_periods"))
	if periods < 3:
		es.set("score_board_period", messages("half_time"))
	else:
		es.set("score_board_period", messages("period_break"))

	name_t = es.ServerVar("sm_match_name_t")
	name_ct = es.ServerVar("sm_match_name_ct")
	if es.ServerVar("sm_match_swap_names_on") == 0:
		message = "%s - %s" % (name_t, name_ct)
	else:
		message = "%s - %s" % (name_ct, name_t)
	es.msg("#green", message)

	match_length = periods * int(es.ServerVar("sm_match_period_length"))

	match_minutes = int(math.floor(match_length / 60))
	match_seconds = int(match_length - (match_minutes * 60))

	period_break_length = int(es.ServerVar("sm_match_period_break_length"))

	match_break_minutes = int(math.floor(period_break_length / 60))
	match_break_seconds = int(period_break_length - (match_break_minutes * 60))

	tokens = {}
	tokens["periods"] = periods

	if match_seconds < 10:
		tokens["length"] = "%s:0%s" % (match_minutes, match_seconds)
	else:
		tokens["length"] = "%s:%s" % (match_minutes, match_seconds)

	if match_break_seconds < 10:
		tokens["break_length"] = "%s:0%s" % (match_break_minutes, match_break_seconds)
	else:
		tokens["break_length"] = "%s:%s" % (match_break_minutes, match_break_seconds)

	for ply in playerlib.getPlayerList("#human"):
		es.server.queuecmd('usermsg hudhint %s "%s"' % (ply.userid, messages("match_message", tokens, ply.get("lang"))))

	freeze_match()

	es.doblock("soccer_mod_2011/modules/stats/reset_score_sheet")

	es.server.queuecmd("mp_restartgame %s" % (es.ServerVar("sm_match_restart_length")))

def pause_match(userid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.ServerVar("sm_match_started") == 1:
		if es.ServerVar("match_paused") == 0:
			es.set("match_paused", 1)

			freeze_match()

			tokens["name"] = player.name
			lang_msg("match_paused", tokens)
		else:
			es.tell(userid, "#green", messages("already_paused", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages("no_match_started", tokens, player.get("lang")))

def unpause_match(userid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.ServerVar("sm_match_started") == 1:
		if es.ServerVar("match_paused") == 1:
			tokens["name"] = player.name
			if es.ServerVar("period_break_running") == 0:
				if es.ServerVar("match_paused_delay") == 0:
					es.set("match_paused_delay", 1)

					lang_msg("get_ready", tokens, 1)
					gamethread.delayed(1, tell_all, ("| 5 |"))
					gamethread.delayed(2, tell_all, ("| 4 |"))
					gamethread.delayed(3, tell_all, ("| 3 |"))
					gamethread.delayed(4, tell_all, ("| 2 |"))
					gamethread.delayed(5, tell_all, ("| 1 |"))
					gamethread.delayed(6, lang_msg, ("go", tokens, 1))

					gamethread.delayed(6, unfreeze_match)

					gamethread.delayed(6, es.set, ("match_paused_delay", 0))
					gamethread.delayed(6, es.set, ("match_paused", 0))

					lang_msg("match_unpaused", tokens)
			else:
				es.set("match_paused_delay", 0)
				es.set("match_paused", 0)

				unfreeze_match()

				lang_msg("match_unpaused", tokens)
		else:
			es.tell(userid, "#green", messages("already_unpaused", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages("no_match_started", tokens, player.get("lang")))

def stop_match(userid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.ServerVar("sm_match_started") == 1:
		load_variables()

		unfreeze_match()

		tokens["name"] = player.name
		lang_msg("match_stopped", tokens)
	else:
		es.tell(userid, "#green", messages("no_match_started", tokens, player.get("lang")))

def stop_match_vote():
	if es.ServerVar("sm_match_started") == 1:
		load_variables()

		unfreeze_match()

def freeze_match():
	for ply in playerlib.getPlayerList("#alive"):
		ply.freeze(1)

	es.server.queuecmd("phys_pushscale 1")
	es.server.queuecmd("phys_timescale 0")

def unfreeze_match():
	for ply in playerlib.getPlayerList("#alive"):
		ply.freeze(0)

	es.server.queuecmd("phys_pushscale 900")
	es.server.queuecmd("phys_timescale 1")

# ******************** Unload ********************
def unload():
	popuplib.delete("sm_popup_admin_match")

	for item in modules:
		es.unload("soccer_mod_2011/modules/match/%s" % (item))