﻿import es
import gamethread
import langlib
import playerlib
import popuplib

lang_dir = "cstrike/addons/eventscripts/soccer_mod_2011/language/"

messages_common = langlib.Strings(lang_dir + "messages_common.ini")
messages_text = langlib.Strings(lang_dir + "modules/referee/messages_referee.ini")
popup_common = langlib.Strings(lang_dir + "popup_common.ini")
popup_text = langlib.Strings(lang_dir + "modules/referee/popup_admin_referee.ini")

required = ["warn", "punish"]

# ******************** Load ********************
def load():
	create_popup()

	for item in required:
		es.load("soccer_mod_2011/modules/referee/%s" % (item))

# ******************** Events ********************
def es_map_start(event_var):
	delete_keys()

def player_spawn(event_var):
	if es.ServerVar("soccer_mod_allowed") == 1:
		if es.exists("key", "soccer_mod_red_card", event_var["es_steamid"]) == 1:
			change_team(event_var["userid"])

# ******************** Create popup ********************
def create_popup():
	popup = popuplib.create("sm_popup_admin_referee")

	popup.addline("SOCCER MOD %s" % (popup_text("title")))
	popup.addline(" ")
	popup.addline("->1. %s" % (popup_text("warn")))
	popup.addline("->2. %s" % (popup_text("yellow")))
	popup.addline("->3. %s" % (popup_text("red")))
	popup.addline("->4. %s" % (popup_text("clear")))
	popup.addline("->5. %s" % (popup_text("punish")))
	popup.addline(" ")
	popup.addline("->9. %s" % (popup_common("back")))
	popup.addline(" ")
	popup.addline("->0. %s" % (popup_common("close")))

	popup.submenu(1, "sm_popup_admin_referee_warn")
	popup.select(2, select_card)
	popup.select(3, select_card)
	popup.select(4, clear_cards)
	popup.submenu(5, "sm_popup_admin_referee_punish")

	for i in range(6, 9):
		popup.submenu(i, "sm_popup_admin_referee")

	popup.submenu(9, "sm_popup_admin")

# ******************** Popup choice ********************
def select_card(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	myPopup = popuplib.easymenu(name, None, give_card)

	if choice == 2:
		type = "yellow"
	elif choice == 3:
		type = "red"

	myPopup.settitle(messages_text("select_player_%s" % (type)))

	for ply in playerlib.getPlayerList("#human"):
		if es.exists("key", "soccer_mod_yellow_card", ply.steamid) == 1:
			myPopup.addoption("%s_%s" % (ply.userid, type), "%s (Yellow)" % (ply.name))
		else:
			myPopup.addoption("%s_%s" % (ply.userid, type), ply.name)

	myPopup.submenu(10, "sm_popup_admin_referee")

	popuplib.send(name, userid)

def clear_cards(userid, choice, popupid):
	delete_keys()

	tokens = {}
	tokens["name"] = es.getplayername(userid)
	lang_msg("clear", tokens)

	popuplib.send("sm_popup_admin_referee", userid)

# ******************** Easymenu choice ********************
def give_card(userid, choice, popupname):
	tokens = {}
	player = playerlib.getPlayer(userid)

	type = choice.split("_")
	if es.exists("userid", type[0]) == 1:
		steamid = es.getplayersteamid(type[0])
		if es.exists("key", "soccer_mod_red_card", steamid) == 0:
			tokens["name"] = player.name
			tokens["target"] = es.getplayername(type[0])

			if type[1] == "yellow":
				if es.exists("keygroup", "soccer_mod_yellow_card") == 0:
					es.keygroupcreate("soccer_mod_yellow_card")

				if es.exists("key", "soccer_mod_yellow_card", steamid) == 0:
					es.keycreate("soccer_mod_yellow_card", steamid)
				else:
					if es.exists("keygroup", "soccer_mod_red_card") == 0:
						es.keygroupcreate("soccer_mod_red_card")

					es.keycreate("soccer_mod_red_card", steamid)

				if es.exists("key", "soccer_mod_red_card", steamid) == 0:
					play_sound(es.ServerVar("sm_referee_sound_whistle"))

					lang_msg("yellow_given", tokens)
				else:
					play_sound(es.ServerVar("sm_referee_sound_whistle"))
					gamethread.delayed(0.5, play_sound, (es.ServerVar("sm_referee_sound_red_card")))

					gamethread.delayed(6, change_team, (type[0]))

					lang_msg("2nd_yellow_given", tokens)

			elif type[1] == "red":
				if es.exists("keygroup", "soccer_mod_red_card") == 0:
					es.keygroupcreate("soccer_mod_red_card")

				es.keycreate("soccer_mod_red_card", steamid)

				play_sound(es.ServerVar("sm_referee_sound_whistle"))
				gamethread.delayed(0.5, play_sound, (es.ServerVar("sm_referee_sound_red_card")))

				gamethread.delayed(6, change_team, (type[0]))

				lang_msg("red_given", tokens)
		else:
			es.tell(userid, "#green", messages_text("already_red", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages_common("no_player_found", tokens, player.get("lang")))

	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	popuplib.send("sm_popup_admin_referee", userid)

# ******************** Functions ********************
def lang_msg(text, tokens):
	for player in playerlib.getPlayerList("#human"):
		es.tell(player.userid, "#green", messages_text(text, tokens, player.get("lang")))

def play_sound(sound):
	es.cexec_all("playgamesound", sound)

def change_team(userid):
	player = playerlib.getPlayer(userid)
	if player.team > 1:
		es.server.queuecmd("es_changeteam %s 1" % (userid))

def delete_keys():
	if es.exists("keygroup", "soccer_mod_yellow_card") == 1:
		es.keygroupdelete("soccer_mod_yellow_card")

	if es.exists("keygroup", "soccer_mod_red_card") == 1:
		es.keygroupdelete("soccer_mod_red_card")

# ******************** Unload ********************
def unload():
	delete_keys()

	popuplib.delete("sm_popup_admin_referee")

	for item in required:
		es.unload("soccer_mod_2011/modules/referee/%s" % (item))